@@ -16,19 +16,15 @@
 #ifndef PLAYLISTSPLITTER_H
 #define PLAYLISTSPLITTER_H
 
-#include <kfiledialog.h>
+#include <QSplitter>
 
-#include <qwidgetstack.h>
+class Q3WidgetStack;
 
-#include "playlistbox.h"
-
-class KActionMenu;
-class KDirWatch;
-class PlaylistItem;
+class Playlist;
 class SearchWidget;
-class HistoryPlaylist;
 class PlaylistInterface;
 class TagEditor;
+class PlaylistBox;
 
 /**
  * This is the main layout class of JuK.  It should contain a PlaylistBox and
@@ -44,10 +40,16 @@ class PlaylistSplitter : public QSplitter
     Q_OBJECT
 
 public:
-    PlaylistSplitter(QWidget *parent, const char *name = 0);
+    explicit PlaylistSplitter(QWidget *parent, const char *name = 0);
     virtual ~PlaylistSplitter();
 
-    PlaylistInterface *playlist() const { return m_playlistBox; }
+    PlaylistInterface *playlist() const;
+
+    virtual bool eventFilter(QObject *watched, QEvent *event);
+
+public slots:
+    virtual void setFocus();
+    virtual void slotFocusCurrentPlaylist();
 
 private:
 
@@ -55,7 +57,7 @@ private:
      * This returns a pointer to the first item in the playlist on the top
      * of the QWidgetStack of playlists.
      */
-    Playlist *visiblePlaylist() const { return m_playlistBox->visiblePlaylist(); }
+    Playlist *visiblePlaylist() const;
 
     void setupActions();
     void setupLayout();
@@ -73,10 +75,13 @@ private slots:
     void slotPlaylistChanged(QWidget *w);
 
 private:
+    Playlist *m_newVisible;
     PlaylistBox *m_playlistBox;
     SearchWidget *m_searchWidget;
-    QWidgetStack *m_playlistStack;
+    Q3WidgetStack *m_playlistStack;
     TagEditor *m_editor;
 };
 
 #endif
+
+// vim: set et sw=4 tw=0 sta:
