@@ -14,10 +14,12 @@
 
   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-  Boston, MA 02111-1307, USA.
+  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  Boston, MA 02110-1301, USA.
 */
 
+#include "synchttplookup.h"
+
 #include <qstringlist.h>
 #include <qapplication.h>
 
@@ -25,8 +27,6 @@
 #include <kio/job.h>
 #include <kio/netaccess.h>
 
-#include "synchttplookup.h"
-
 namespace KCDDB
 {
   SyncHTTPLookup::SyncHTTPLookup()
@@ -39,7 +39,7 @@ namespace KCDDB
     // Empty.
   }
 
-    CDDB::Result
+    Result
   SyncHTTPLookup::lookup
   (
     const QString         & hostName,
@@ -47,9 +47,6 @@ namespace KCDDB
     const TrackOffsetList & trackOffsetList
   )
   {
-    if ( trackOffsetList.count() < 3 )
-      return UnknownError;
-
     trackOffsetList_ = trackOffsetList;
 
     initURL( hostName, port );
@@ -60,7 +57,7 @@ namespace KCDDB
     if ( Success != result_ )
       return result_;
 
-    kdDebug(60010) << matchList_.count() << " matches found." << endl;
+    kDebug(60010) << matchList_.count() << " matches found.";
 
     if (matchList_.isEmpty())
       return NoRecordFound;
@@ -79,7 +76,7 @@ namespace KCDDB
     return result_;
   }
 
-    CDDB::Result
+    Result
   SyncHTTPLookup::runQuery()
   {
     data_ = QByteArray();
@@ -90,12 +87,12 @@ namespace KCDDB
     if ( Success != result_ )
       return result_;
 
-    kdDebug(60010) << "runQuery() Result: " << resultToString(result_) << endl;
+    kDebug(60010) << "runQuery() Result: " << resultToString(result_);
 
     return result_;
   }
 
-    CDDB::Result
+    Result
   SyncHTTPLookup::matchToCDInfo( const CDDBMatch & match )
   {
     data_ = QByteArray();
@@ -109,12 +106,12 @@ namespace KCDDB
     return result_;
   }
 
-    CDDB::Result
+    Result
   SyncHTTPLookup::fetchURL()
   {
-    kdDebug(60010) << "About to fetch: " << cgiURL_.url() << endl;
+    kDebug(60010) << "About to fetch: " << cgiURL_.url();
 
-    KIO::TransferJob* job = KIO::get( cgiURL_, false, false );
+    KIO::TransferJob* job = KIO::get( cgiURL_, KIO::NoReload, KIO::HideProgressInfo );
 
     if ( 0 == job )
       return ServerError;
